@@ -9,12 +9,13 @@ from oauth2client.client import GoogleCredentials
 import base64
 
 
-def credhub_get_credentials(output_option='FILE'):
+def credhub_get_credentials(name=None, output_option='FILE'):
     """Return credhub managed credentials  in pivotal cloud  at runtime from `VCAP_SERVICES` environment variable.
 
     documentatioin: https://docs.pivotal.io/credhub-service-broker/using.html
 
     Keyword Arguments:
+        name {str, list} -- Credhub credential ``Instance Name``  or list of instance names. If not provided, the function attampts to retrieve all credentials (default: None)
         output_option {str,dict} -- output format of credentials.
                 {{'key': 'env_variable'}: 'downloads credential ``value`` to a temp file, sets ``env_variable`` for each credential ``key`` pointing to the temp file path' \
                 'FILE':'downloads credential ``value`` as a temp file, sets credential ``key`` as variable pointing to temp file path'\
@@ -32,7 +33,17 @@ def credhub_get_credentials(output_option='FILE'):
     service = os.environ.get('VCAP_SERVICES')
     if service:
         env = json.loads(service)
-        cred_name = [cred.get('name') for cred in env.get('credhub')]
+        if name:
+            if isinstance(name, str):
+                cred_name = [cred.get('instance_name') for cred in env.get(
+                    'credhub') if cred.get('instance_name') == name]
+            else:
+                cred_name = [cred.get('instance_name') for cred in env.get(
+                    'credhub') if cred.get('instance_name') in name]
+        else:
+            cred_name = [cred.get('instance_name')
+                         for cred in env.get('credhub')]
+
         logging.debug(f"names of available credentials: {cred_name}")
     else:
         logging.error(f"cred hub or VCAP_SERVICES is not available")
@@ -41,13 +52,16 @@ def credhub_get_credentials(output_option='FILE'):
     if cred_name:
         temp_files = []
         creds = {}
-        credhub = [cred.get('credentials') for cred in env.get('credhub')]
+        credhub = [cred.get('credentials') for cred in env.get(
+            'credhub') if cred.get('instance_name') in cred_name]
+
         if isinstance(output_option, dict):
             env_mapping = list(output_option.items())
 
         for i, name in enumerate(cred_name):
 
             key, value = zip(*credhub[i].items())
+
             key, value = key[0], value[0]
 
             if output_option != 'DICT':
